@@ -56,8 +56,10 @@ plotHelper <- function(code = "", colours = NULL, returnCode = FALSE) {
   # Whether or not we attached ggplot2 and hence need to detach it at the end
   ggdetach <- FALSE
 
+  addin <- (substitute(code) == ".colourpicker_addin_text")
+
   # Use default code if none was given
-  if (trimws(code) == "") {
+  if ((addin || is.character(substitute(code))) && trimws(code) == "") {
     code <- "ggplot(iris, aes(Sepal.Length, Petal.Length)) +
       geom_point(aes(col = Species)) +
       scale_colour_manual(values = CPCOLS)"
@@ -73,7 +75,7 @@ plotHelper <- function(code = "", colours = NULL, returnCode = FALSE) {
   }
   # If code was given, parse it and save it
   else {
-    if (!is.character(code)) {
+    if (!addin && !is.character(substitute(code))) {
       code <- paste(deparse(substitute(code)), collapse = " ")
     }
 
@@ -111,24 +113,22 @@ plotHelper <- function(code = "", colours = NULL, returnCode = FALSE) {
     colours <- rep_len(palette, colours)
   }
 
-  resourcePath <- system.file("gadgets", "colourpicker",
-                              package = "colourpicker")
-  shiny::addResourcePath("cpg", resourcePath)
+  shiny::addResourcePath("cpg", system.file("gadgets", "colourpicker", package = "colourpicker"))
 
   ui <- miniPage(
     shinyjs::useShinyjs(),
     shinyjs::extendShinyjs(
-      script = file.path(resourcePath, "js", "shinyjs-funcs.js"),
+      script = file.path("cpg", "js", "shinyjs-funcs.js"),
       functions = c("closeWindow")
     ),
     tags$head(
-      includeCSS(file.path(resourcePath, "css", "app.css")),
-      includeCSS(file.path(resourcePath, "css", "plotHelper.css"))
+      tags$link(rel="stylesheet", href = file.path("cpg", "css", "app.css")),
+      tags$link(rel="stylesheet", href = file.path("cpg", "css", "plotHelper.css"))
     ),
 
     gadgetTitleBar(span(strong("Plot Colour Helper"),
                         span(id = "author", "By",
-                             a(href = "http://deanattali.com", "Dean Attali")))
+                             a(href = "https://deanattali.com", "Dean Attali")))
     ),
 
     div(id = "plotArea",
@@ -159,7 +159,7 @@ plotHelper <- function(code = "", colours = NULL, returnCode = FALSE) {
             title = "Add another colour"
         ),
         div(id = "removeColBtn",
-            icon("trash-o"),
+            icon("trash-alt"),
             title = "Remove selected colour"
         ),
         uiOutput("selectedCols", inline = TRUE)
@@ -566,9 +566,9 @@ plotHelper <- function(code = "", colours = NULL, returnCode = FALSE) {
 
 plotHelperAddin <- function() {
   context <- rstudioapi::getActiveDocumentContext()
-  text <- context$selection[[1]]$text
+  .colourpicker_addin_text <- context$selection[[1]]$text
 
-  code <- plotHelper(text, returnCode = TRUE)
+  code <- plotHelper(.colourpicker_addin_text, returnCode = TRUE)
   if (is.null(code)) {
     return()
   }
